@@ -15,8 +15,8 @@ class Fetch:
         self._outer = outer
         self._client = client
 
-    async def __call__(self, id: int) -> Comment:
-        id36 = to_base36(id)
+    async def __call__(self, idn: int) -> Comment:
+        id36 = to_base36(idn)
         return await self.by_id36(id36)
 
     async def by_id36(self, id36: str) -> Comment:
