@@ -36,7 +36,7 @@ if TYPE_CHECKING:
 import os.path as op
 from functools import cached_property
 
-from ...http.payload import guess_filename_mimetype
+from ...http.util.guess_filename_mimetype import guess_filename_mimetype
 from ...models.widget.widget_image_upload_lease import WidgetImageUploadLease
 from ...models.widget.SYNC import WidgetList
 from ...model_loaders.widget import load_widget_image_upload_lease
@@ -315,7 +315,7 @@ class WidgetProcedures:
         ) -> None:
             resp = self._client.http.request('POST', upload_lease.endpoint,
                     data=upload_lease.fields, files={'file': file}, timeout=timeout)
-            resp.raise_for_status()
+            resp.ensure_successful_status()
 
         def upload(self,
             file: IO[bytes],
@@ -486,7 +486,7 @@ class WidgetProcedures:
 
     create: cached_property[Create] = cached_property(Create)
 
-    class Update:
+    class Replace:
         def __init__(self, outer: WidgetProcedures) -> None:
             self._client = outer._client
 
@@ -695,7 +695,7 @@ class WidgetProcedures:
             root = self._invoke(sr, idt, json=json)
             return load_rules_widget(root)
 
-    update: cached_property[Update] = cached_property(Update)
+    replace: cached_property[Replace] = cached_property(Replace)
 
     def create_menu_bar_tabs(self,
         sr: str,
@@ -710,7 +710,7 @@ class WidgetProcedures:
         root = self._client.request('POST', f'/r/{sr}/api/widget', json=json)
         return load_menu_bar(root)
 
-    def update_menu_bar_tabs(self,
+    def replace_menu_bar_tabs(self,
         sr: str,
         idt: str,
         *,
